.. Copyright (c) 2016, Johan Mabille, Sylvain Corlay and Wolf Vollprecht

   Distributed under the terms of the BSD 3-Clause License.

   The full license is in the file LICENSE, distributed with this software.

Basic functions
===============

**xtensor** provides the following basic functions for xexpressions and scalars:

Defined in ``xtensor/xmath.hpp``

.. _abs-function-reference:
.. doxygenfunction:: abs(E&&)
   :project: xtensor

.. _fabs-function-reference:
.. doxygenfunction:: fabs(E&&)
   :project: xtensor

.. _fmod-function-reference:
.. doxygenfunction:: fmod(E1&&, E2&&)
   :project: xtensor

.. _remainder-func-ref:
.. doxygenfunction:: remainder(E1&&, E2&&)
   :project: xtensor

.. _fma-function-reference:
.. doxygenfunction:: fma(E1&&, E2&&, E3&&)
   :project: xtensor

.. _maximum-func-ref:
.. doxygenfunction:: maximum(E1&&, E2&&)
   :project: xtensor

.. _minimum-func-ref:
.. doxygenfunction:: minimum(E1&&, E2&&)
   :project: xtensor

.. _fmax-function-reference:
.. doxygenfunction:: fmax(E1&&, E2&&)
   :project: xtensor

.. _fmin-function-reference:
.. doxygenfunction:: fmin(E1&&, E2&&)
   :project: xtensor

.. _fdim-function-reference:
.. doxygenfunction:: fdim(E1&&, E2&&)
   :project: xtensor

.. _clip-function-reference:
.. doxygenfunction:: clip(E1&&, E2&&, E3&&)
   :project: xtensor

.. _sign-function-reference:
.. doxygenfunction:: sign(E&&)
   :project: xtensor

